// 1D example
// kriging model creation parameter estimation
// EGO object creation, optimization example

function [y]=gpeak(x) // sample objective function
y=sin(x*3)-exp(-(x+0.1)^2/0.01)  
endfunction;


ftest=gpeak;
x_bound=[-1; 1];

 
noise=0;
X=(linspace(x_bound(1),x_bound(2),6))';// six initial points
YExp=ftest(X); // response 

Xtest=(linspace(x_bound(1),x_bound(2),100))'; // test points

// creaate initial kriging model
//[kmodel] =km(X,YExp,0,'gaussian',1,0);
[kmodel] =km(X,YExp,0,'matern_5_2',1,0);
//kmodel.estimateNoise=0;
[kmodel p]=findTheta(kmodel,0.001,1,'MLL','RS',500);// estimate parameters ( Random Search)

// ego boundaries
lob=[-1];
upb=[1];
maxit=9;

opt=EGO(kmodel,lob,upb,maxit,0.00000001,'RS',500,,%t); // creates EGO object ( RS for EI minimization)
//opt=EGO(kmodel,lob,upb,maxit,0.00000001,'NM'); // creates EGO object ( NM for EI minimization)
yx=[];vy=[];
while ~EGO_stop(opt)   // runs optimizer
//
  [x,opt]=EGO_ask(opt);
  opt=EGO_tell(opt,x,ftest(x));
  [yx(:,opt.it),vy(:,opt.it)]=predict(opt.kmodel,Xtest); /// save data for ploting
  [yb,xb]=EGO_best(opt);
 
end;

///////////////////////////////////////////////////////////////// ploting

scf;
for i=1: opt.it
rows=ceil(sqrt(opt.it)); 

c=modulo(i,rows);if c==0 then c=rows;end;
r=ceil(i/rows);
xsetech([(c-1)*(1/rows),(r-1)*(1/rows),(1/rows),(1/rows)]);


plot(X,YExp,'k+');
plot(Xtest,ftest(Xtest),'k');


plot(Xtest,yx(:,i),'b');//kriging mean

plot(Xtest,vy(:,i),'r');//kriging variance

plot(opt.perfData.maxEix(1:i),ftest(opt.perfData.maxEix(1:i)),'ro');// points from previous iteration
plot(opt.perfData.maxEix(i),ftest(opt.perfData.maxEix(i)),'r.'); // current point
end;


///////////////////////// plot EI for each iteration
scf;
for it=1:opt.it
rows=ceil(sqrt(opt.it)); 

c=modulo(it,rows);if c==0 then c=rows;end;
r=ceil(it/rows); 
xsetech([(c-1)*(1/rows),(r-1)*(1/rows),(1/rows),(1/rows)]);
plot(opt.perfData.xEis(it),opt.perfData.Eis(it),'+');
end;



