function [opt]=EGO_tell(opt,x,y)
//Tell EGO optimizer new data point and criterion value.
//  
// Calling Sequence
//          opt=EGO_tell(opt,x,y)
//      
//
// Parameters
//            opt: mlist of type EGO.
//            x: new data point, row vector.
//            y:  response (criterion) value at x.
// Output
//            
//            opt: updated optimizer (mlist of type EGO).
//
//Description 
//
//          Tell EGO optimizer new data point and criterion value.
//Examples
// //See EGO or demos.
//
//See also  
//              EGO
//              EGO_stop
//              EGO_best
//              EGO_ask
//              EI
//              km
//              findTheta
//              
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography   
//           Jones D.R., Schonlau M. and Welch W.J. (1998), Efficient Global Optimization of Expensive Black-Box Functions, Journal of Global optimization, 13:, 455-492.
//Pujol G., Le Riche R. (2007). Description de l'architecture Scilab pour le projet RNTL/OMD.
//
  
  
global S_kriging Y_kriging Beta_kriging;
//[model] =km([S_kriging;x],[Y_kriging,y],opt.model.trend,opt.model.cov,opt.model.theta,opt.model.noise);
Xnew=[S_kriging;x];
Ynew=[Y_kriging;y];

if y<= opt.fmin then opt.fmin=y; opt.xmin=x;end;

// create kriging model
oldmodel=opt.kmodel;
[model]=km(Xnew, Ynew, opt.kmodel.trend, opt.kmodel.cov, opt.kmodel.theta, opt.kmodel.noise,Beta_kriging,opt.kmodel.sigma,opt.kmodel.silent)

model.estimateNoise=oldmodel.estimateNoise;
model.estimateBeta=oldmodel.estimateBeta;
model.estimateSigma=oldmodel.estimateSigma;



//thetaLow=opt.kmodel.theta*0.3;
//thetaLow=ones(opt.lob)*0.001;
thetaLow=(opt.upb-opt.lob)/1000;
//thetaHigh=opt.kmodel.theta*1.7;
thetaHigh=(opt.upb-opt.lob)*2;

[opt.kmodel ]=findTheta(model,opt.kmodel.optimizer.lob,opt.kmodel.optimizer.upb,opt.kmodel.optimizer.crit,       opt.kmodel.optimizer.method,opt.kmodel.optimizer.maxiter,opt.kmodel.optimizer.params);
//[opt.kmodel ]=findTheta(opt.kmodel,opt.kmodel.theta*0.3,opt.kmodel.theta*1.7,'CV','RS',500);
//opt.kmodel=model;

if or(opt.kmodel.theta == opt.kmodel.optimizer.lob) | or(opt.kmodel.theta == opt.kmodel.optimizer.upb) then printf('\n Theta on boundary.\n');end;
if opt.perf then
  // saves performance data
  
    opt.perfData.maxEiy=[opt.perfData.maxEiy; y];
    opt.perfData.fmin=[opt.perfData.fmin; opt.fmin];
    
end;
endfunction
