
function [model]=CorrMatrix(model)
//
//Creates correlation matrix for kriging model based on correlation function and hyper-parameters.
//  
// Call:
//            [model]=CorrMatrix(model)
//
//
// Input:
//            model - mlist of type kmodel created previously.     
//              model.alfa
//              model.noise
//              model.sigma
// Output:
//            model - updated kriging model.
//
//              
//
// Note:
//          This function uses global variable D_kriging and sets R_kriging.
//
global D_kriging R_kriging dR_kriging;




m=model.m;
n=model.n;

R_kriging=zeros(m,m);

if model.cov == 'gaussian' then 
funct=1; 
// Gaussian covariance implemented in c
//R_kriging=call("corr_D",D_kriging,1,"d",model.theta,2,"d",m,3,"i",size(D_kriging,'r'),4,"i",n,5,"i",funct,6,"i","out",[m,m],7,"d");
//pause;
R_kriging=c_corr_D(D_kriging,model.theta,funct,m);
elseif  model.cov == 'matern_5_2' then 
funct=2;
//R_kriging=call("corr_D",D_kriging,1,"d",model.theta,2,"d",m,3,"i",size(D_kriging,'r'),4,"i",n,5,"i",funct,6,"i","out",[m,m],7,"d");
R_kriging=c_corr_D(D_kriging,model.theta,funct,m);

else
					//those covariance functions that are not implemented in c

					if model.cov == 'exponential_1' then funct=exponential_1;
					elseif model.cov == 'exponential_1_9' then funct=exponential_1_9;
					end

					ii=1;
					for i=1:m-1
							for j=i+1:m
										R_kriging(i,j)=funct(D_kriging(ii,:),model.theta);
										ii=ii+1;
								
							end;
					end;

					R_kriging=R_kriging+eye(R_kriging);
end;




if model.estimateNoise == -1 then
  R_kriging=model.alfa*R_kriging+(1-model.alfa)*eye(R_kriging);
  
    //model.coefcov=v;
end;

if model.estimateNoise==0 then
  R_kriging=R_kriging+model.noise*eye(R_kriging); // To add small noise for numerical stability.
  
//  model.coefcov=model.sigma; 
end;

if model.estimateNoise==1 then
  R_kriging=model.sigma*R_kriging+model.noise*eye(R_kriging);
  
//  model.coefcov=1;
end;

dR_kriging=%nan;

endfunction
