function [model]=EstimateVar(model)
//Calculates process variance and noise for kriging model.
//  
//  Calling Sequence
//            [model]=EstimateVar(model)
//
//
//  Parameters
//            model: mlist of type kmodel created previously.     
//
// Output
//            model: updated kriging model.
//Description
//            Calculates process variance and noise for kriging model.
//              Updates 
//              model.sigma - estimated process variance, 
//              model.noise - estimated noise, 
//              model.coefcov - parameter, that links correlation matrix to covariance matrix. C= model.coefcov*R;
//
// Note:
//          This function uses global variables  Tyfb_kriging Ty_kriging.
//         
//Examples
// 
//See also
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

global Tyfb_kriging;

if model.estimateNoise == -1 then
  // unknown noise
  
  v=(1/model.m)*(Tyfb_kriging'*Tyfb_kriging);
  
  if model.estimateSigma==-1 then
    //unknown sigma
    model.noise=v*(1-model.alfa);
    model.sigma=v-model.noise;
      
  elseif model.estimateSigma==1 then 
    //known sigma
    model.noise=v-model.sigma;
    
  end;
  model.coefcov=v;
    
elseif model.estimateNoise==1 then
    // known noise
   model.coefcov=1;
 
elseif  model.estimateNoise==0 then
   // zerro noise
  if model.estimateSigma==-1 then model.sigma=(1/model.m)*(Tyfb_kriging'*Tyfb_kriging);  end;
  model.coefcov=model.sigma; 
else 
  
  // error
end;

endfunction;




