function [R]=createCorr(X,theta,fcov)
// Creates correlation matrix R.
//
//
//Calling Sequence
//            R=createCorr(X,theta,fcov)
//
//Parameters
//            X: data points (m*n). Rows representing data points.
//            theta: parameters of correlation fuction. Row vector.
//            fcov: pointer to  correlation function.
//
// Output
//           R: correlation matrix  (m*m).
//
//Description
// Creates correlation matrix R. Used in  simGaussian and SimCondGaussian.
//
//Examples
//X=RLHS(10,3,[1 1 3],[2 4 4])
//R=createCorr(X,[1 1 1],'gaussian')
//
//See also
//           simGaussian
//           SimCondGaussian
//           findTheta
//           km
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//
[m,n]=size(X);
//normalize X;

R=zeros(m,m);

if fcov == 'gaussian' then

// Gaussian covariance implemented in c
//n=size(theta,'c');
funct=1;
//R=call("corr_X",X,1,"d",theta,2,"d",m,3,"i",n,4,"i",funct,5,"i","out",[m,m],6,"d");
R=c_corr_X(X,theta,funct);
elseif  fcov == 'matern_5_2' then 
funct=2;
//R=call("corr_X",X,1,"d",theta,2,"d",m,3,"i",n,4,"i",funct,5,"i","out",[m,m],6,"d");
R=c_corr_X(X,theta,funct);
else
					if fcov == 'exponential_1' then funct=exponential_1;
					elseif fcov == 'exponential_1_9' then funct=exponential_1_9;
					end


//for covariance functions that are not implemented in c

					for i=1:m-1
							for j=i+1:m
												R(i,j)=funct(X(i,:)-X(j,:),theta);
							end;
					end;
					R=R+R'+eye(R);
end;




endfunction;


