function decompose_estBeta(model)
//Preforms Cholesky decomposition for covariance/correlation matrix. Calculates T_kriging M_kriging Ty_kriging frf_kriging Tyfb_kriging and estimates Beta_kriging  if necessary.
//
//
//  
//  Calling Sequence
//            decompose_estBeta(kmodel);
//
//
// Parameters
//            model: mlist of type kmodel created previously.     
//
//Description
//         Performs Cholesky decomposition for covariance/correlation matrix. Calculates T_kriging M_kriging Ty_kriging frf_kriging Tyfb_kriging and estimates Beta_kriging  if necessary. This function sets global variables T_kriging M_kriging Ty_kriging frf_kriging Tyfb_kriging Beta_kriging.
//
// 
//         
//Examples
// See demos directory for more examples.
//See also
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//
  
  global R_kriging Y_kriging T_kriging M_kriging F_kriging Ty_kriging frf_kriging Tyfb_kriging Beta_kriging;

  
  T_kriging=chol(R_kriging);//Cholesky decomposition R_kriging=T_kriging'*T_kriging// T_kriging- upper triangular
  
  M_kriging=(T_kriging')\(F_kriging); //   Solves LS M_kriging=(T_kriging'inv * F_kriging); M_kriging is a n*p matrix  

  Ty_kriging=(T_kriging')\(Y_kriging);

  mm=((M_kriging')*M_kriging);
  if mm==0 then frf_kriging=0;  // this check needed in case F_kriging==0
  else    frf_kriging=inv(mm); end;


  if model.estimateBeta==-1 then Beta_kriging=frf_kriging*((M_kriging')*Ty_kriging); end;  //estimates Beta_kriging   

  Tyfb_kriging=(T_kriging')\(Y_kriging-F_kriging*Beta_kriging);
endfunction


