function [model] = logLL(model)
//Calculates negative log Likelihood.
//  
//  Calling Sequence
//            [model] = logLL(model)
//
//
// Parameters
//            model: mlist of type kmodel created previously.     
//
//Description
//Calculates negative log-Likelihood, depending on values of  model.estimateNoise and model.estimateSigma.
// Sets model.MLL.
//
//   This function uses global variables  Y_kriging T_kriging Ty_kriging Tyfb_kriging.
//
//         
//Examples
// See demos directory for more examples.
//See also
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//
 
global Y_kriging T_kriging Ty_kriging Tyfb_kriging;
m=size(Y_kriging,'r'); 

if model.estimateNoise == -1 then 
      //unknown homogeneous noise - for  estimation of theta, noise (and sigma if needed)
    //model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma+model.noise)+2*log(prod(diag(T_kriging)))+m);
	model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma+model.noise)+2*sum(log(diag(T_kriging)))+m);
    
elseif model.estimateNoise == 0  then
  // zero noise
  if model.estimateSigma==-1 then
   // for estimation of theta and sigma
    //model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma)+2*log(prod(diag(T_kriging)))+m);
	model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma)+2*sum(log(diag(T_kriging)))+m);
  
  elseif model.estimateSigma==1 
     // for estimation of theta only
    //model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma)+2*log(prod(diag(T_kriging)))+Tyfb_kriging'*Tyfb_kriging/(model.sigma));  
	model.MLL=-0.5*(m*log(2*%pi)+m*log(model.sigma)+2*sum(log(diag(T_kriging)))+Tyfb_kriging'*Tyfb_kriging/(model.sigma)); // more stable numerically
  else
    model.MLL=%nan;
  end;

elseif model.estimateNoise == 1 then
    // known noise - for estimation of theta (and sigma if needed)
     
  //model.MLL=-0.5*(m*log(2*%pi)+2*log(prod(diag(T_kriging)*sqrt(model.coefcov)))+Tyfb_kriging'*Tyfb_kriging/model.coefcov);
  model.MLL=-0.5*(m*log(2*%pi)+2*sum(log(diag(T_kriging)*sqrt(model.coefcov)))+Tyfb_kriging'*Tyfb_kriging/model.coefcov);// more stable numerically
else model.MLL=%nan;
end;

//model.sigma=sigma; 
      
model.MLL=-model.MLL;      
model.dMLL=%nan;  
endfunction
