function [f,df]=poly1(x)
//Linear trend function.
//
//Calling Sequence
//          f = poly1(x)
//
// Parameters
//         x:  m*n matrix with design sites
// Output
//        f: [1 S]
//        df: derivatives(not implemented);
//
//Description
//First order polynomial trend function.
//Examples
//
//// 1D example
//// zero noise
//x_bound=[-2; 2];
//X=(linspace(x_bound(1),x_bound(2),4))'; // Points of experiment
//YExp=sin(X);// Response values
//noise=0;theta=1;
//[kmodel] =km(X,YExp,poly1,'gaussian',theta,noise);
//[kmodel] =km(X,YExp,1,'gaussian',theta,noise);
//
//
//See also
//           poly0
//           poly2
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

  [m,n] = size(x);
  f = [ones(m,1),x];
  
endfunction;

