function [f,df]=poly2(x)
//Quadratic trend function.
//
//Calling Sequence
//          f = poly2(x)
//          [f, df] = poly2(x)
//
// Parameters
//         x:  m*n matrix with design sites
// Output
//        f:  [1 S S(:,1)*S S(:,2)S(:,2:n) ... S(:,n)^2]
//        df:  derivatives(not implemented);
//
//
//Description
//Second order polynomial trend function.
//Examples
//
//// 1D example
//// zero noise
//x_bound=[-2; 2];
//X=(linspace(x_bound(1),x_bound(2),4))'; // Points of experiment
//YExp=sin(X);// Response values
//noise=0;theta=1;
//[kmodel] =km(X,YExp,poly2,'gaussian',theta,noise);
//[kmodel] =km(X,YExp,2,'gaussian',theta,noise);
//
//
//See also
//           poly0
//           poly1
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

[nargout, nargin] = argn();

[m n] = size(x);
nn = (n+1)*(n+2)/2;  // Number of columns in f  


f = [ones(m,1) x zeros(m,nn-n-1)];

j = n+1;   q = n;
for  k = 1 : n
  f(:,j+(1:q)) = (ones(1,q) .*. x(:,k)) .* x(:,k:n);
  j = j+q;   q = q-1;
end;

dv=%nan;
endfunction;
