function [f,df]=poly3(x)
//Cubic trend function (without factor interactions).
//
//Calling Sequence
//          f = poly3(x)
//          [f, df] = poly3(x)
//
// Parameters
//         x:  m*n matrix with design sites
// Output
//        f:  [1 S S.*S  S.*S.*S]
//        df:  derivatives(not implemented);
//
//
//Description
//Third order  polynomial trend function without interactions.
//Examples
//
//// 1D example
//// zero noise
//x_bound=[-2; 2];
//X=(linspace(x_bound(1),x_bound(2),4))'; // Points of experiment
//YExp=sin(X);// Response values
//noise=0;theta=1;
//[kmodel] =km(X,YExp,poly3,'gaussian',theta,noise);
//[kmodel] =km(X,YExp,3,'gaussian',theta,noise);
//
//
//See also
//           poly0
//           poly1
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

[nargout, nargin] = argn();

[m n] = size(x);
nn = (n+1)*(n+2)/2;  // Number of columns in f  


f = [ones(m,1) x x.*x x.*x.*x];


dv=%nan;
endfunction;
