function [mY,vY]=predict(model,x);
//Calculates predicted kriging mean and variance at points x;
//
//  Calling Sequence
//													[my]=predict(model,x);
//													[my,vy]=predict(model,x);
//
//
// Parameters
//            mode: mlist of type kmodel created previously.
//            x: points for prediction, m*n matrix, m - number of points, n - number of dimensions, each row represents one point). If x represents one point both - column and row vector is accepted.
//            
//
// 
//            mY: column vector (m*1) containing predicted mean at points x.
//            vY: column vector (m*1) containing estimated variance at points x.
//
//Description
//      Calculates predicted kriging mean and variance at points x.
//          This function uses global variables Ty T_kriging Beta_kriging M_kriging Tyfb_kriging frf_kriging.
//          Variance is estimated using formulas for Simple Kriging  or Universal Kriging based on value model.estimateBeta.
//
//Examples
// See demos directory for more examples.
//See also
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//
  
global Ty T_kriging Beta_kriging M_kriging Tyfb_kriging frf_kriging ;//S_kriging; 
 global Tkx;   
   [nx ny]=size(x);
   if model.n > 1 then 
	if ny==1 then x=x';[nx ny]=size(x); end;
   end;

  if (ny~= model.n) then error('Dimensions for prediction points is different from kriging model points'); end;

//Normalize input data
    x = (x - (ones(nx,ny) .*. model.scS(1,:))) ./ (ones(nx,ny) .*. model.scS(2,:));

 
					my=zeros(nx,1);
					vy=zeros(nx,1);

    f=(model.trend(x))';
      
     kx=model.sigma*CorrVectorData(model,x);// correlation between data points end experiments
     Tkx=(T_kriging')\kx; // invT*kx
     
     my=f'*Beta_kriging+(1/model.coefcov)*(Tkx'*Tyfb_kriging);//Mean of UK. divide by total variance C=coefcov*R;   invC=1/coefcov *invR
      

					lhs=argn(1)

										//
										//version with no for loop
					 if lhs>1 then // calculate variance only if needed
					//													vy(j)=model.sigma- (1/model.coefcov)*((Tkx(:,j)')*Tkx(:,j));//  variance of SK
										vy=model.sigma- (1/model.coefcov)*(sum((Tkx(:,:).^2),'r'))';
							

												if model.estimateBeta==-1 then // variance considering trend estimation - UK

															tmp=f'-(1/model.coefcov)*Tkx'*M_kriging;
															vy=vy+(model.coefcov)*sum((tmp*frf_kriging).*tmp,'c');
															end;
							end;					
															


 	vy(find(vy<%eps*(model.sigma+model.noise)| vy<%eps*10))=0; // finds all vy that are very small and sets to 0; Assumes that variance is negative becouse of numerical error.


// Scale predictor back 
mY = (model.scY(1,:) + model.scY(2,:) .* my);

vY=(model.scY(2,:).^2).*vy; 

endfunction
