
function [LH]=RLHS(maxiter,n,lob,upb)
//  Creates RLH sampling of maxiter points for n dimensions in the interval [lob,upb].
//
// Calling Sequence    
//          LH=RLHS(maxiter,n,lob,upb)
// Parameters
//          maxiter:  number of points.
//          n:  number of dimensions.
//          lob: row vector (1*n). Lower boundaries.
//          upb: row vector (1*n). Upper boundaries.
// 
//
//          LH - matrix (maxiter*n) of Latin Hypercube sampling.
//
//Description        
//  Creates Random Latin Hypercube sampling of maxiter points for n dimensions in the interval [lob,upb].
//Examples
//          LH=RLHS(10,2,[1 2],[1.5, 3])
//See also
//
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
// 
  
   tmp=grand(n,'prm',(1:maxiter)');// Generates n random permutations of 1:maxiter

      xold=ones(2,n);
      xold(2,:)=xold(2,:)*maxiter;
      
      xnew=ones(2,n);
      xnew(1,:)=ones(1,n).*lob;
      xnew(2,:)=ones(1,n).*upb;
      LH=rescale(tmp,xnew,xold);
endfunction;

