function  [f]=rescale(X,xnew,xold)
// Rescales X.
//
//Calling Sequence
//   [f]=rescale(X,xnew,xold)
//
//Parameters
//      X: matrix (m*n) of data values, m rows represents m data points, n columns data dimensions.;
//      xold: current boundaries. xold(1,:) old low boundary for all dimensions n; xold(2,:) old high boundary for all dimensions n.If not given, takes min(X) as low and max(X) as high boundary for every dimensions n.
//      xnew: new boundaries. xnew(1,:) new low boundary for all dimensions n; xnew(2,:) new high boundary for all dimensions n.
//Description
//Rescales X, where xold(1,:)<X<xold(2,:), to f, where xnew(1,:)<f<xnew(2,:).
//         
//Examples
//xold=[1 2; 2 3]
//xnew=[-1 -3; 0 3]
//X=[linspace(1,2,10);linspace(2,3,10)]'
//rescale(X,xnew)
//
//X=RLHS(10,3,[ 0 0 0],[1 1 1]);
//X=rescale(X,[ -1 0 -3;2 1 5]);
//
//See also
//           km
//           findTheta
//           simGaussian
//           SimCondGaussian
//   
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

[lhs,rhs]=argn(0)  
if  rhs <3 then xold(1,:)= min(X,'r');
                xold(2,:)= max(X,'r');
   end
  
[n1,m1]=size(xold);
// if i-th dimension has only one value, then scales to the middle
for i=1:m1 
  if (xold(2,i)-xold(1,i))==0 then xold(2,i)=xold(2,i)+1;xold(1,i)=xold(1,i)-1;end
  //if (xold(2,:)-xold(1,:))==0 then xold(2,:)=xold(2,:)+1;xold(1,:)=xold(1,:)-1;
end

[n,m]=size(X); 
[ n2,m2]=size(xnew); 
if n1 <> n2 | m1<> m2 | n1<2 | m1 <> m then 
    T = 'Error: Matrix or array size are not correct.';
    error(T);
end;

for i=1:n
  f(i,:)=(X(i,:)-xold(1,:)).*(xnew(2,:)-xnew(1,:))./(xold(2,:)-xold(1,:))+xnew(1,:);
end
endfunction


