
/* ==================================================================== */
#include "stack-c.h"
#include "api_scilab.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "corr_functions.h"
/* ==================================================================== */
/* Returns correlation matrix (dm*dm) between points in D (distances between experiment points).
	* D						- matrix (m1xn1) of distances, m1 - number of points n1- number of dimensions
	* Theta		- range parameters (n2).
	*	dVArFunct - correlation kernel
	* dm				- number of points (correlation matrix size)
	*
	* called from CorrMatrix.sci
	*
	* scilab code:
	* 				ii=1;
					for i=1:dm-1
							for j=i+1:dm
										R(i,j)=funct(D(ii,:),model.theta);
										ii=ii+1;
								
							end;
					end;

					R=R+R';
					R=R+eye(R);

	*/
int sci_corr_D(char *fname)
{
  SciErr sciErr;

  int i = 0;
  int m1 = 0, n1 = 0, m2=0,n2=0, ii=0, k=0,j=0;

	int *piAddressVarOne = NULL;
  int *piAddressVarTwo = NULL;
  int *piAddressVarThree = NULL;
  int *piAddressVarFour = NULL;


  double dVarFunct = 0.0;
  int dm = 0;
  double tmp=0.0;
  double *matrixOfDoubleD = NULL;
  double *matrixOfDoubleTheta = NULL;
  double *matrixOfDoubleOut = NULL;
  

  int iType1 = 0;
  int iType2 = 0;
  int iType3 = 0;
  int iType4 = 0;


  // Parameters: 1- Matrix D,  2- Vector for theta, 3 - covariance function type, 4 - number of points ( dm)  
	
	CheckRhs(4,4) ;
  CheckLhs(1,1) ;   
  
  /* get Address of inputs */
  sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVarOne);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 sciErr = getVarType(pvApiCtx, piAddressVarOne, &iType1);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 


  sciErr = getVarAddressFromPosition(pvApiCtx, 2, &piAddressVarTwo);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  sciErr = getVarType(pvApiCtx, piAddressVarTwo, &iType2);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 

	  sciErr = getVarAddressFromPosition(pvApiCtx, 3, &piAddressVarThree);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }

   if ( !isDoubleType(pvApiCtx, piAddressVarThree) )
  {
    Scierror(999,"%s: Wrong type for input argument #%d: A scalar expected.\n", fname, 3);
    return 0;
  }

 
  sciErr = getVarAddressFromPosition(pvApiCtx, 4, &piAddressVarFour);//type cast to int later
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
   if ( !isDoubleType(pvApiCtx, piAddressVarFour) )
  {
    Scierror(999,"%s: Wrong type for input argument #%d: A scalar expected.\n", fname, 4);
    return 0;
  }


 /* get values */
  /* get matrix */
  sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarOne, &m1, &n1, &matrixOfDoubleD);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
   
   sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarTwo, &m2, &n2, &matrixOfDoubleTheta);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  
  
  if ( getScalarDouble(pvApiCtx, piAddressVarThree, &dVarFunct) )
  {
    Scierror(999,"%s: Wrong size for input argument #%d: A scalar expected.\n", fname, 3);
    return 0;
  }
  
 if (getScalarDouble(pvApiCtx, piAddressVarFour, &tmp) )//type cast to int later
  {
    Scierror(999,"%s: Wrong size for input argument #%d: A scalar expected.\n", fname, 4);
    return 0;
  }
  	
 dm=(int)tmp;
  // Argument as copy
    matrixOfDoubleOut= (double*)malloc(sizeof(double) * dm *dm);

   switch ((int)dVarFunct) {
    case 1://gaussian
       ii=0;
       for (i=0; i < dm; i++) {
        for (k=i+1; k < dm; k++) {
         matrixOfDoubleOut[i+k*dm]=1;
         for ( j=0; j<n1; j++)	{
          matrixOfDoubleOut[i+k*dm]=matrixOfDoubleOut[i+k*dm]*gaussian(matrixOfDoubleD[ii+j*m1],matrixOfDoubleTheta[j]);	// callculates gaussian covariance
         }
         ii++;
         matrixOfDoubleOut[i*dm+k]=	matrixOfDoubleOut[i+k*dm];
       }
       matrixOfDoubleOut[i+i*dm]=1;
      }
	  break;
	case 2: // matern_5_2
		   ii=0;
       for (i=0; i < dm; i++) {
        for (k=i+1; k < dm; k++) {
         matrixOfDoubleOut[i+k*dm]=1;
         for ( j=0; j<n1; j++)	{
					 tmp=matrixOfDoubleD[ii+j*m1];
					 if (tmp <0) { tmp=-tmp;}
					 matrixOfDoubleOut[i+k*dm]=matrixOfDoubleOut[i+k*dm]*matern_5_2(tmp,matrixOfDoubleTheta[j]);	// callculates gaussian covariance
         }
         ii++;
         matrixOfDoubleOut[i*dm+k]=	matrixOfDoubleOut[i+k*dm];
       }
       matrixOfDoubleOut[i+i*dm]=1;
      }
	  break;

		default:
	//  Code to execute if <variable> does not equal the value following any of the cases
		Scierror(999,"%s: No such covariance function, check variable  #%d:\n", fname, 3);
	  break;
	}

 																							

/* Create the matrix as return of the function */
  createMatrixOfDouble(pvApiCtx, Rhs + 1, dm, dm, matrixOfDoubleOut);
  if(sciErr.iErr)
  {
      printError(&sciErr, 0);
      return 0;
  }

  LhsVar(1) = Rhs + 1; 
  
  /* This function put on scilab stack, the lhs variable
  which are at the position lhs(i) on calling stack */
  /* You need to add PutLhsVar here because WITHOUT_ADD_PUTLHSVAR 
  was defined and equal to %t */
  /* without this, you do not need to add PutLhsVar here */
  PutLhsVar();
  
  return 0;
}
/* ==================================================================== */


