
/* ==================================================================== */
#include "stack-c.h"
#include "api_scilab.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "corr_functions.h"
/* ==================================================================== */
/* Returns correlation matrix between points in X (m1xm1).
	* 	X					-matrix (m1xn1) of points , m1 - number of points n1- number of dimensions
	*		Theta		- range parameters (1xn2).
	*		dVArFunct - correlation kernel
	*
	* Called form createCorr.sci;
	*
	*
	*Scilab code:
	*
	*
											for i=1:m-1
												for j=i+1:m
																	R(i,j)=fcov(X(i,:)-X(j,:),theta);
												end;
										end;
										R=R+R'+eye(R);
										end;
	*
	*
	*/

int sci_corr_X(char *fname)
{
  SciErr sciErr;

  int i = 0;
  int m1 = 0, n1 = 0, m2=0,n2=0, k=0,j=0;

	int *piAddressVarOne = NULL;
  int *piAddressVarTwo = NULL;
  int *piAddressVarThree = NULL;
 // int *piAddressVarFour = NULL;


  double dVarFunct = 0.0;
  //int dm = 0;
  double tmp=0.0;
  double *matrixOfDoubleX = NULL;
  double *matrixOfDoubleTheta = NULL;
  double *matrixOfDoubleOut = NULL;
  

  int iType1 = 0;
  int iType2 = 0;
  int iType3 = 0;
  //int iType4 = 0;


  // Parameters: 1- matrix of points,  2- Vector for theta, 3 - covariance function type
  CheckRhs(3,3) ;
  CheckLhs(1,1) ;   
  
  /* get Address of inputs */
  sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVarOne);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 sciErr = getVarType(pvApiCtx, piAddressVarOne, &iType1);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 


  sciErr = getVarAddressFromPosition(pvApiCtx, 2, &piAddressVarTwo);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  sciErr = getVarType(pvApiCtx, piAddressVarTwo, &iType2);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 

	  sciErr = getVarAddressFromPosition(pvApiCtx, 3, &piAddressVarThree);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }

   if ( !isDoubleType(pvApiCtx, piAddressVarThree) )
  {
    Scierror(999,"%s: Wrong type for input argument #%d: A scalar expected.\n", fname, 3);
    return 0;
  }

 
  /* get values */
  /* get matrix */
  sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarOne, &m1, &n1, &matrixOfDoubleX);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
   
   sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarTwo, &m2, &n2, &matrixOfDoubleTheta);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  
  
  if ( getScalarDouble(pvApiCtx, piAddressVarThree, &dVarFunct) )
  {
    Scierror(999,"%s: Wrong size for input argument #%d: A scalar expected.\n", fname, 3);
    return 0;
  }
  
  	
 //dm=(int)tmp;
  // Argument as copy
    matrixOfDoubleOut= (double*)malloc(sizeof(double) * m1 *m1);

   switch ((int)dVarFunct) {
    case 1://gaussian
       for (i=0; i < m1; i++) {
        for (k=i+1; k < m1; k++) {
         matrixOfDoubleOut[i+k*m1]=1;
         for ( j=0; j<n1; j++)	{
          matrixOfDoubleOut[i+k*m1]=matrixOfDoubleOut[i+k*m1]*gaussian(matrixOfDoubleX[k+j*m1]-matrixOfDoubleX[i+j*m1],matrixOfDoubleTheta[j]);	// callculates gaussian covariance

					//sciprint("%f %f %f\n",matrixOfDoubleX[k*m1+j],matrixOfDoubleX[i*m1+j],matrixOfDoubleTheta[j]);
         }
        matrixOfDoubleOut[k+i*m1]=	matrixOfDoubleOut[i+k*m1];
       }
       matrixOfDoubleOut[i+i*m1]=1;
      }
	  break;
	case 2: // matern_5_2
			 for (i=0; i < m1; i++) {
        for (k=i+1; k < m1; k++) {
         matrixOfDoubleOut[i+k*m1]=1;
         for ( j=0; j<n1; j++)	{
					 tmp=matrixOfDoubleX[k+j*m1]-matrixOfDoubleX[i+j*m1];
					 if (tmp <0) { tmp=-tmp;}
					 matrixOfDoubleOut[i+k*m1]=matrixOfDoubleOut[i+k*m1]*matern_5_2(tmp,matrixOfDoubleTheta[j]);	// callculates gaussian covariance
         }
        matrixOfDoubleOut[k+i*m1]=	matrixOfDoubleOut[i+k*m1];
       }
       matrixOfDoubleOut[i+i*m1]=1;
      }
	  break;

		default:
	//  Code to execute if <variable> does not equal the value following any of the cases
		Scierror(999,"%s: No such covariance function, check variable  #%d:\n", fname, 3);
	  break;
	}

 																							

/* Create the matrix as return of the function */
  createMatrixOfDouble(pvApiCtx, Rhs + 1, m1, m1, matrixOfDoubleOut);
  if(sciErr.iErr)
  {
      printError(&sciErr, 0);
      return 0;
  }

  LhsVar(1) = Rhs + 1; 
  
  /* This function put on scilab stack, the lhs variable
  which are at the position lhs(i) on calling stack */
  /* You need to add PutLhsVar here because WITHOUT_ADD_PUTLHSVAR 
  was defined and equal to %t */
  /* without this, you do not need to add PutLhsVar here */
  PutLhsVar();
  
  return 0;
}
/* ==================================================================== */


