
/* ==================================================================== */
#include "stack-c.h"
#include "api_scilab.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "corr_functions.h"
/* ==================================================================== */
/* Returns correlation matrix between point x and data points S.
/*
	* 	S				-matrix (m1xn1) of points , m1 - number of points n1- number of dimensions
	* 	x					-points for wich to callculate the correlation (m2xn2)
	*	 Theta		- range parameters (1xn3).
	*		dVArFunct - correlation kernel
	* Output is (m1xm2)
	*
	* Called form corrVectorData.sci;
	*
	* To access X(i,j)  (mxn)  use X[i+j*m]  
	*
	*
	* *Scilab code:
	*
	*
	*								for i=1:t 
															for k=1:model.m
																							kx(k,i)=funct(S(k,:)-x(i,:),model.theta);
															end;
										end;


										for i=1:model.m
													kx(i)=funct(S(i,:)-x,model.theta);
										end;

	*
	*
	*/
int sci_corr_vector(char *fname)
{
  SciErr sciErr;

  int i = 0;
  int m1 = 0, n1 = 0, m2=0,n2=0,m3=0,n3=0, ii=0, k=0,j=0;

	int *piAddressVarOne = NULL;
  int *piAddressVarTwo = NULL;
  int *piAddressVarThree = NULL;
	  int *piAddressVarFour = NULL;



  double dVarFunct = 0.0;
    double tmp=0.0;
  double *matrixOfDoubleS = NULL;
	double *matrixOfDoublex = NULL;
  double *matrixOfDoubleTheta = NULL;

  double *matrixOfDoubleOut = NULL;
  

  int iType1 = 0;
  int iType2 = 0;
  int iType3 = 0;
  


  // Parameters: 1- Matrix D, 2- matrix of x points,  3- Vector for theta, 4 - covariance function type
	CheckRhs(4,4) ;
  CheckLhs(1,1) ;   
  
  /* get Address of inputs */
  sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVarOne);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 sciErr = getVarType(pvApiCtx, piAddressVarOne, &iType1);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 


  sciErr = getVarAddressFromPosition(pvApiCtx, 2, &piAddressVarTwo);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  sciErr = getVarType(pvApiCtx, piAddressVarTwo, &iType2);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
 

	  sciErr = getVarAddressFromPosition(pvApiCtx, 3, &piAddressVarThree);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
	  sciErr = getVarType(pvApiCtx, piAddressVarThree, &iType3);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
	
	sciErr = getVarAddressFromPosition(pvApiCtx, 4, &piAddressVarFour);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }

   if ( !isDoubleType(pvApiCtx, piAddressVarFour) )
  {
    Scierror(999,"%s: Wrong type for input argument #%d: A scalar expected.\n", fname, 4);
    return 0;
  }

 /* get values */
  /* get matrix */
  sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarOne, &m1, &n1, &matrixOfDoubleS);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
   
   sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarTwo, &m2, &n2, &matrixOfDoublex);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  
  sciErr = getMatrixOfDouble(pvApiCtx, piAddressVarThree, &m3, &n3, &matrixOfDoubleTheta);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  
	if ( getScalarDouble(pvApiCtx, piAddressVarFour, &dVarFunct) )
  {
    Scierror(999,"%s: Wrong size for input argument #%d: A scalar expected.\n", fname, 4);
    return 0;
  }

  // Argument as copy
    matrixOfDoubleOut= (double*)malloc(sizeof(double) * m1 *m2);

   switch ((int)dVarFunct) {
    case 1://gaussian
       for (i=0; i < m2; i++) {
        for (k=0; k < m1; k++) {
         matrixOfDoubleOut[k+i*m1]=1;
         for ( j=0; j<n1; j++)	{
          matrixOfDoubleOut[k+i*m1]=matrixOfDoubleOut[k+i*m1]*gaussian(matrixOfDoubleS[k+j*m1]-matrixOfDoublex[i+j*m2],matrixOfDoubleTheta[j]);	// callculates gaussian covariance
         }
        }
      }
	  break;
	case 2: // matern_5_2
		   for (i=0; i < m2; i++) {
        for (k=0; k < m1; k++) {
         matrixOfDoubleOut[k+i*m1]=1;
         for ( j=0; j<n1; j++)	{
					 tmp=(matrixOfDoubleS[k+j*m1]-matrixOfDoublex[i+j*m2]);
					 if (tmp <0) { tmp=-tmp;}
					 matrixOfDoubleOut[k+i*m1]=matrixOfDoubleOut[k+i*m1]*matern_5_2(tmp,matrixOfDoubleTheta[j]);	// callculates gaussian covariance
         }
        }
      }
	  break;

		default:
	//  Code to execute if <variable> does not equal the value following any of the cases
		Scierror(999,"%s: No such covariance function, check variable  #%d:\n", fname, 3);
	  break;
	}

 																							

/* Create the matrix as return of the function */
  createMatrixOfDouble(pvApiCtx, Rhs + 1, m1, m2, matrixOfDoubleOut);
  if(sciErr.iErr)
  {
      printError(&sciErr, 0);
      return 0;
  }

  LhsVar(1) = Rhs + 1; 
  
  /* This function put on scilab stack, the lhs variable
  which are at the position lhs(i) on calling stack */
  /* You need to add PutLhsVar here because WITHOUT_ADD_PUTLHSVAR 
  was defined and equal to %t */
  /* without this, you do not need to add PutLhsVar here */
  PutLhsVar();
  
  return 0;
}
/* ==================================================================== */


